# TODO

- Documentation
  - Tutorial
  - Reference

- Add tests!!!

- mlflow integration:
  - define how.

- Action loops for grid search and similar approaches:
  - grid search driver.
  - gradient descent search driver.
  - nested config, database and working directory support.
  - join actions afterwards.
  - parallelization actions.

- Action testing:
  - pre and post conditions.

- Error handling

- SQL parsing and manipulation:
  - For instance: SQL table creators with multiple sentences.
  - Template autoquoting.
  - SQL subidiom translation
  - Automatic table dependencies detection

- Dependency management

- Configuration:
  - Improve handling of lists.

- Logging:
  - Set some rules about when and what to log and apply them in the
    framework.

- Downloaders
  - Explore the downloaders idea further.
  - Add support for many more.

- Jupyter support

- Add support for documentation generation.

- Add an Action Standard Library.

- Databricks/Spark integration?

- Release as Open Source?
